==> stork-2.3.1.tar.gz: stork-2.3.1/AUTHORS.md <==
Stork authors and contributors
------------------------------

Primary developers:

- Marcin Siodelski (maintainer, database, server, agent, UI, config management,
                    config review, Kea, BIND 9, PowerDNS, DNS zone viewer)
- Sławek Figiel (maintainer, database, server, agent, UI, hooks, LDAP, system tests,
                 registration, config migration, config review, Prometheus,
                 Kea statistics)
- Piotrek Zadroga (maintainer, UI, responsive UI, version reporting, DNS zone viewer,
                   read-only user role)

Active developers:

- Tomek Mrugalski (documentation, testing, Kea, project management)
- Vicky Risk (product management, marketing)
- Włodek Wencel (QA, release engineering)
- Andrei Pavel (CI, release engineering, UI)
- Marcin Godzina (QA, release engineering)
- Suzanne Goldlust (documentation)
- William Leuschner
- Yavor Peev (QA)

Primary area of work mentioned in parentheses. The list is in
roughly chronological order.

Former developers:

- Razvan Becheriu (database, server, UI)
- Thomas Markwalder (Kea)
- Matthijs Mekking (BIND 9, Prometheus)
- Michał Nowikowski (maintainer, server, agent, UI, Prometheus, release engineering)

We have received the following contributions:

 - Franek Górski
   - 2019-09: Grafana template
 - Yannick Martin (OVHCloud)
   - 2021-05: Fix for Stork agent not honoring the listen-only flags
 - Kevin Fleming
   - 2022-03: Automatic Stork services restart on failure
 - Mark Tinberg (University of Wisconsin-Madison)
   - 2024-02: Enhanced the package installation scripts
 - Robin Berger
   - 2024-03: Separated DN used in various contexts in the LDAP hook.

==> stork-2.3.2.tar.gz: stork-2.3.2/AUTHORS.md <==
Stork authors and contributors
------------------------------

Primary developers:

- Marcin Siodelski (maintainer, database, server, agent, UI, config management,
                    config review, Kea, BIND 9, PowerDNS, DNS zone viewer)
- Sławek Figiel (maintainer, database, server, agent, UI, hooks, LDAP, system tests,
                 registration, config migration, config review, Prometheus,
                 Kea statistics)
- Piotrek Zadroga (maintainer, UI, responsive UI, version reporting, DNS zone viewer,
                   read-only user role)

Active developers:

- Tomek Mrugalski (documentation, testing, Kea, project management)
- Vicky Risk (product management, marketing)
- Włodek Wencel (QA, release engineering)
- Andrei Pavel (CI, release engineering, UI)
- Marcin Godzina (QA, release engineering)
- Suzanne Goldlust (documentation)
- William Leuschner

Primary area of work mentioned in parentheses. The list is in
roughly chronological order.

Former developers:

- Razvan Becheriu (database, server, UI)
- Thomas Markwalder (Kea)
- Matthijs Mekking (BIND 9, Prometheus)
- Michał Nowikowski (maintainer, server, agent, UI, Prometheus, release engineering)
- Yavor Peev (QA)

We have received the following contributions:

 - Franek Górski
   - 2019-09: Grafana template
 - Yannick Martin (OVHCloud)
   - 2021-05: Fix for Stork agent not honoring the listen-only flags
 - Kevin Fleming
   - 2022-03: Automatic Stork services restart on failure
 - Mark Tinberg (University of Wisconsin-Madison)
   - 2024-02: Enhanced the package installation scripts
 - Robin Berger
   - 2024-03: Separated DN used in various contexts in the LDAP hook.
 - Benjamin Solenthaler
   - 2025-11: Fix for editing host reservation with an IPv6 prefix.
 - Lucas Petrino
   - 2025-11: Fix for monitor Kea listening on IPv6 address.
